@@ -1,4 +1,6 @@
 """Constants for the Z-Wave JS python library."""
+from __future__ import annotations
+
 from enum import Enum, IntEnum
 from importlib import metadata
 
@@ -6,9 +8,9 @@ PACKAGE_NAME = "zwave-js-server-python"
 __version__ = metadata.version(PACKAGE_NAME)
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 26
+MIN_SERVER_SCHEMA_VERSION = 27
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 26
+MAX_SERVER_SCHEMA_VERSION = 27
 
 VALUE_UNKNOWN = "unknown"
 
@@ -345,3 +347,18 @@ class ProvisioningEntryStatus(IntEnum):
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/controller/Inclusion.ts#L136
     ACTIVE = 0
     INACTIVE = 1
+
+
+class SecurityBootstrapFailure(IntEnum):
+    """Enum with all security bootstrap failure reasons."""
+
+    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/controller/Inclusion.ts#L16
+    USER_CANCELED = 0
+    NO_KEYS_CONFIGURED = 1
+    S2_NO_USER_CALLBACKS = 2
+    TIMEOUT = 3
+    PARAMETER_MISMATCH = 4
+    NODE_CANCELED = 5
+    S2_INCORRECT_PIN = 6
+    S2_WRONG_SECURITY_LEVEL = 7
+    UNKNOWN = 8
