@@ -1,7 +1,8 @@
 """Provide a model for the Z-Wave JS controller's events."""
-from typing import Dict, Literal, Type
+from __future__ import annotations
+
+from typing import Literal, TypedDict
 
-from ...const import TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED
 from ...event import BaseEventModel
 from ..node.data_model import FoundNodeDataType, NodeDataType
 from .firmware import (
@@ -11,16 +12,12 @@ from .firmware import (
 from .inclusion_and_provisioning import InclusionGrantDataType
 from .statistics import ControllerStatisticsDataType
 
-if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
 
 class InclusionResultDataType(TypedDict, total=False):
     """Represent an inclusion result data dict type."""
 
-    lowSecurity: bool
+    lowSecurity: bool  # required
+    lowSecurityReason: int
 
 
 class BaseControllerEventModel(BaseEventModel):
@@ -72,14 +69,14 @@ class HealNetworkDoneEventModel(BaseControllerEventModel):
     """Model for `heal network done` event data."""
 
     event: Literal["heal network done"]
-    result: Dict[int, str]
+    result: dict[int, str]
 
 
 class HealNetworkProgressEventModel(BaseControllerEventModel):
     """Model for `heal network progress` event data."""
 
     event: Literal["heal network progress"]
-    progress: Dict[int, str]
+    progress: dict[int, str]
 
 
 class InclusionAbortedEventModel(BaseControllerEventModel):
@@ -171,7 +168,7 @@ class ValidateDSKAndEnterPINEventModel(BaseControllerEventModel):
     dsk: str
 
 
-CONTROLLER_EVENT_MODEL_MAP: Dict[str, Type["BaseControllerEventModel"]] = {
+CONTROLLER_EVENT_MODEL_MAP: dict[str, type["BaseControllerEventModel"]] = {
     "exclusion failed": ExclusionFailedEventModel,
     "exclusion started": ExclusionStartedEventModel,
     "exclusion stopped": ExclusionStoppedEventModel,
