@@ -1,5 +1,7 @@
 """Data model for a Z-Wave JS node."""
-from typing import List, Literal, Optional, TypedDict, Union
+from __future__ import annotations
+
+from typing import Literal, TypedDict
 
 from ..device_class import DeviceClassDataType
 from ..device_config import DeviceConfigDataType
@@ -13,8 +15,8 @@ class FoundNodeDataType(TypedDict, total=False):
 
     nodeId: int
     deviceClass: DeviceClassDataType
-    supportedCCs: List[int]
-    controlledCCs: List[int]
+    supportedCCs: list[int]
+    controlledCCs: list[int]
 
 
 class NodeDataType(TypedDict, total=False):
@@ -32,11 +34,11 @@ class NodeDataType(TypedDict, total=False):
     zwavePlusNodeType: int
     zwavePlusRoleType: int
     isListening: bool
-    isFrequentListening: Union[bool, str]
+    isFrequentListening: bool | str
     isRouting: bool
     maxDataRate: int
-    supportedDataRates: List[int]
-    isSecure: Union[bool, Literal["unknown"]]
+    supportedDataRates: list[int]
+    isSecure: bool | Literal["unknown"]
     supportsBeaming: bool
     supportsSecurity: bool
     protocolVersion: int
@@ -49,14 +51,14 @@ class NodeDataType(TypedDict, total=False):
     keepAwake: bool
     ready: bool
     label: str
-    endpoints: List[EndpointDataType]
+    endpoints: list[EndpointDataType]
     endpointCountIsDynamic: bool
     endpointsHaveIdenticalCapabilities: bool
     individualEndpointCount: int
     aggregatedEndpointCount: int
     interviewAttempts: int
-    interviewStage: Optional[Union[int, str]]
-    values: List[ValueDataType]
+    interviewStage: int | str | None
+    values: list[ValueDataType]
     statistics: NodeStatisticsDataType
     highestSecurityClass: int
     isControllerNode: bool
