@@ -1,6 +1,8 @@
 """Common models for statistics."""
-from dataclasses import dataclass
-from typing import TYPE_CHECKING, List, Optional, Tuple, TypedDict
+from __future__ import annotations
+
+from dataclasses import dataclass, field
+from typing import TYPE_CHECKING, TypedDict
 
 from zwave_js_server.exceptions import RepeaterRssiErrorReceived, RssiErrorReceived
 
@@ -15,47 +17,49 @@ class RouteStatisticsDataType(TypedDict, total=False):
     """Represent a route statistics data dict type."""
 
     protocolDataRate: int
-    repeaters: List[int]
+    repeaters: list[int]
     rssi: int
-    repeaterRSSI: List[int]
-    routeFailedBetween: List[int]
+    repeaterRSSI: list[int]
+    routeFailedBetween: list[int]
 
 
 class RouteStatisticsDict(TypedDict):
     """Represent a route statistics data dict type."""
 
     protocol_data_rate: int
-    repeaters: List["Node"]
-    rssi: Optional[int]
-    repeater_rssi: List[int]
-    route_failed_between: Optional[Tuple["Node", "Node"]]
+    repeaters: list["Node"]
+    rssi: int | None
+    repeater_rssi: list[int]
+    route_failed_between: tuple["Node", "Node"] | None
 
 
 @dataclass
 class RouteStatistics:
     """Represent route statistics."""
 
-    def __init__(self, client: "Client", data: RouteStatisticsDataType) -> None:
-        """Initialize route statistics."""
-        self.data = data
-        self.client = client
+    client: "Client"
+    data: RouteStatisticsDataType
+    protocol_data_rate: ProtocolDataRate = field(init=False)
+    repeaters: list["Node"] = field(init=False)
+    route_failed_between: tuple["Node", "Node"] | None = field(init=False, default=None)
 
-    @property
-    def protocol_data_rate(self) -> ProtocolDataRate:
-        """Return protocol data rate."""
-        return ProtocolDataRate(self.data["protocolDataRate"])
-
-    @property
-    def repeaters(self) -> List["Node"]:
-        """Return repeaters."""
+    def __post_init__(self) -> None:
+        """Post initialize."""
+        self.protocol_data_rate = ProtocolDataRate(self.data["protocolDataRate"])
         assert self.client.driver
-        return [
+        self.repeaters = [
             self.client.driver.controller.nodes[node_id]
             for node_id in self.data["repeaters"]
         ]
+        if node_ids := self.data.get("routeFailedBetween"):
+            assert len(node_ids) == 2
+            self.route_failed_between = (
+                self.client.driver.controller.nodes[node_ids[0]],
+                self.client.driver.controller.nodes[node_ids[1]],
+            )
 
     @property
-    def rssi(self) -> Optional[int]:
+    def rssi(self) -> int | None:
         """Return RSSI."""
         if (rssi := self.data.get("rssi")) is None:
             return None
@@ -64,7 +68,7 @@ class RouteStatistics:
         return rssi
 
     @property
-    def repeater_rssi(self) -> List[int]:
+    def repeater_rssi(self) -> list[int]:
         """Return repeater RSSI."""
         repeater_rssi = self.data.get("repeaterRSSI", [])
         rssi_errors = [item.value for item in RssiError]
@@ -73,18 +77,6 @@ class RouteStatistics:
 
         return repeater_rssi
 
-    @property
-    def route_failed_between(self) -> Optional[Tuple["Node", "Node"]]:
-        """Return route failed between."""
-        if (node_ids := self.data.get("routeFailedBetween")) is None:
-            return None
-        assert self.client.driver
-        assert len(node_ids) == 2
-        return (
-            self.client.driver.controller.nodes[node_ids[0]],
-            self.client.driver.controller.nodes[node_ids[1]],
-        )
-
     def as_dict(self) -> RouteStatisticsDict:
         """Return route statistics as dict."""
         return {
