@@ -1,5 +1,7 @@
 """Support for multicast commands."""
-from typing import Any, List, Optional, cast
+from __future__ import annotations
+
+from typing import Any, cast
 
 from ..client import Client
 from ..const import TARGET_VALUE_PROPERTY, CommandClass
@@ -11,8 +13,8 @@ from ..model.value import ValueDataType, _get_value_id_str_from_dict
 async def _async_send_command(
     client: Client,
     command: str,
-    nodes: Optional[List[Node]] = None,
-    require_schema: Optional[int] = None,
+    nodes: list[Node] | None = None,
+    require_schema: int | None = None,
     **kwargs: Any,
 ) -> dict:
     """Send a multicast command."""
@@ -32,13 +34,13 @@ async def async_multicast_set_value(
     client: Client,
     new_value: Any,
     value_data: ValueDataType,
-    nodes: Optional[List[Node]] = None,
-    options: Optional[dict] = None,
+    nodes: list[Node] | None = None,
+    options: dict | None = None,
 ) -> bool:
     """Send a multicast set_value command."""
     assert client.driver
-    # Iterate through nodes specified or all nodes if not specified
-    for node in nodes or client.driver.controller.nodes.values():
+    # Iterate through nodes specified (if any) and validate that the value exists
+    for node in nodes or ():
         # If the value to set is for Basic CC and targetValue property, skip validation
         if (
             value_data["commandClass"] == CommandClass.BASIC
@@ -69,7 +71,7 @@ async def async_multicast_set_value(
 
 
 async def async_multicast_get_endpoint_count(
-    client: Client, nodes: Optional[List[Node]] = None
+    client: Client, nodes: list[Node] | None = None
 ) -> int:
     """Send a multicast get_endpoint_count command."""
     result = await _async_send_command(
@@ -82,7 +84,7 @@ async def async_multicast_endpoint_supports_cc(
     client: Client,
     endpoint: int,
     command_class: CommandClass,
-    nodes: Optional[List[Node]] = None,
+    nodes: list[Node] | None = None,
 ) -> bool:
     """Send a supports_cc command to a multicast endpoint."""
     result = await _async_send_command(
@@ -100,7 +102,7 @@ async def async_multicast_endpoint_get_cc_version(
     client: Client,
     endpoint: int,
     command_class: CommandClass,
-    nodes: Optional[List[Node]] = None,
+    nodes: list[Node] | None = None,
 ) -> int:
     """Send a get_cc_version command to a multicast endpoint."""
     result = await _async_send_command(
@@ -119,8 +121,8 @@ async def async_multicast_endpoint_invoke_cc_api(
     endpoint: int,
     command_class: CommandClass,
     method_name: str,
-    args: Optional[List[Any]] = None,
-    nodes: Optional[List[Node]] = None,
+    args: list[Any] | None = None,
+    nodes: list[Node] | None = None,
 ) -> Any:
     """Send a invoke_cc_api command to a multicast endpoint."""
     result = await _async_send_command(
@@ -140,7 +142,7 @@ async def async_multicast_endpoint_supports_cc_api(
     client: Client,
     endpoint: int,
     command_class: CommandClass,
-    nodes: Optional[List[Node]] = None,
+    nodes: list[Node] | None = None,
 ) -> bool:
     """Send a supports_cc_api command to a multicast endpoint."""
     result = await _async_send_command(
